@@ -81,8 +81,9 @@ class Events(Enum):
     RUNNER_STOPPED = 39
     RUNNER_REMOVED = 40
     JOB_UPDATED = 41
+    JOB_EXECUTED = 43
 
-    # Next: 43
+    # Next: 44
 
 
 class BaseModel(object):
@@ -634,6 +635,7 @@ class Request(RequestTemplate):
         metadata=None,
         hidden=None,
         updated_at=None,
+        status_updated_at=None,
         has_parent=None,
         requester=None,
     ):
@@ -657,6 +659,7 @@ class Request(RequestTemplate):
         self.hidden = hidden
         self.created_at = created_at
         self.updated_at = updated_at
+        self.status_updated_at = status_updated_at
         self.error_class = error_class
         self.has_parent = has_parent
         self.requester = requester
